"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const glob_1 = require("glob");
const path = tslib_1.__importStar(require("path"));
const fs = tslib_1.__importStar(require("fs-extra"));
const handlebars = tslib_1.__importStar(require("handlebars"));
exports.search = (pattern, options = {}) => {
    return new Promise((resolve, reject) => {
        var g = new glob_1.Glob(pattern, Object.assign({ dot: true }, options));
        g.once("end", resolve);
        g.once("error", reject);
    });
};
function renderTemplateString(string, data) {
    const template = handlebars.compile(string);
    return template(data);
}
exports.renderTemplateString = renderTemplateString;
function renderTemplateFile(templateFolderPath, templatePath, data) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const file = yield fs.readFile(templatePath);
        const template = handlebars.compile(file.toString());
        const fullPath = templatePath.replace(".template", "");
        const { dir: parent, base: fileName } = path.parse(fullPath);
        const content = template(data);
        const parentPath = path.relative(templateFolderPath, parent);
        return {
            fileName,
            fullPath,
            parentPath,
            content
        };
    });
}
exports.renderTemplateFile = renderTemplateFile;
function getTemplatedFilePath(filePath, data) {
    const templateMatch = filePath.match(/{{[^}]*}}/);
    if (templateMatch) {
        const normalizedFilePath = filePath.split(path.sep).join(path.posix.sep);
        const renderedFilePath = renderTemplateString(normalizedFilePath, data);
        const denormalizedFilePath = renderedFilePath
            .split(path.posix.sep)
            .join(path.sep);
        return denormalizedFilePath;
    }
    return filePath;
}
exports.getTemplatedFilePath = getTemplatedFilePath;
function measureTime(precision = 0) {
    const start = process.hrtime();
    return () => {
        const elapsed = process.hrtime(start)[1] / 1000000;
        return elapsed.toFixed(precision);
    };
}
exports.measureTime = measureTime;
function getRenderedPath(templatePath, rootPath, newRootPath) {
    return path.join(newRootPath, path.relative(rootPath, templatePath));
}
exports.getRenderedPath = getRenderedPath;
//# sourceMappingURL=utils.js.map